@@ -14,14 +14,16 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
+from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import tables
+from openstack_dashboard.dashboards.project.networks.ports \
+    import tables as port_tables
 from openstack_dashboard import policy
 
 from neutron_fwaas_dashboard.api import fwaas_v2 as api_fwaas_v2
@@ -63,7 +65,7 @@ class DeleteRuleLink(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Rule",
             u"Delete Rules",
             count
@@ -71,7 +73,7 @@ class DeleteRuleLink(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Scheduled deletion of Rule",
             u"Scheduled deletion of Rules",
             count
@@ -95,7 +97,7 @@ class DeletePolicyLink(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Policy",
             u"Delete Policies",
             count
@@ -103,7 +105,7 @@ class DeletePolicyLink(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Scheduled deletion of Policy",
             u"Scheduled deletion of Policies",
             count
@@ -123,7 +125,7 @@ class DeleteFirewallGroupLink(policy.PolicyTargetMixin,
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Firewall Group",
             u"Delete Firewall Groups",
             count
@@ -131,7 +133,7 @@ class DeleteFirewallGroupLink(policy.PolicyTargetMixin,
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Scheduled deletion of Firewall Group",
             u"Scheduled deletion of Firewall Groups",
             count
@@ -139,9 +141,10 @@ class DeleteFirewallGroupLink(policy.PolicyTargetMixin,
 
     def delete(self, request, obj_id):
         try:
-            api_fwaas_v2.firewall_delete(request, obj_id)
+            api_fwaas_v2.firewall_group_delete(request, obj_id)
         except Exception as e:
-            exceptions.handle(request, _('Unable to delete firewall. %s') % e)
+            exceptions.handle(request,
+                              _('Unable to delete firewall group. %s') % e)
 
 
 class UpdateRuleLink(policy.PolicyTargetMixin, tables.LinkAction):
@@ -254,7 +257,13 @@ def get_rules_name(datum):
 
 
 def get_ports_name(datum):
-    return ', '.join([port.name_or_id for port in datum.ports])
+    return len(datum.ports)
+
+
+def get_ports_link(datum):
+    url = reverse("horizon:project:firewalls_v2:firewallgroupdetails",
+                  args=(datum.id,))
+    return '%s?tab=%s__%s' % (url, 'firewallgrouptabs', 'ports_tab')
 
 
 def get_ingress_policy_link(datum):
@@ -289,6 +298,7 @@ class RulesTable(tables.DataTable):
                          verbose_name=_("Name"),
                          link="horizon:project:firewalls_v2:ruledetails")
     description = tables.Column('description', verbose_name=_('Description'))
+    ip_version = tables.Column('ip_version', verbose_name=('IP Version'))
     protocol = tables.Column("protocol",
                              filters=(lambda v: filters.default(v, _("ANY")),
                                       filters.upper,),
@@ -381,6 +391,7 @@ class FirewallGroupsTable(tables.DataTable):
                                               link=get_egress_policy_link,
                                               verbose_name=_("Egress Policy"))
     ports = tables.Column(get_ports_name,
+                          link=get_ports_link,
                           verbose_name=_("Ports"))
 
     status = tables.Column("status",
@@ -403,3 +414,12 @@ class FirewallGroupsTable(tables.DataTable):
             DeleteFirewallGroupLink,
             AddPortToFirewallGroupLink,
             RemovePortFromFirewallGroupLink)
+
+
+class FirewallGroupPortsTable(port_tables.PortsTable):
+
+    class Meta(object):
+        name = 'ports'
+        verbose_name = _('Ports')
+        table_actions = []
+        row_actions = []
